#[repr(u32)]pub enum ErrorCode {
NotApproved = 0,
InvalidOwner = 1,
EmptySupply = 2,
InvalidInput = 3,
IncorrectLpMint = 4,
ExceededSlippage = 5,
ZeroTradingTokens = 6,
NotSupportMint = 7,
InvalidVault = 8,
InitLpAmountTooLess = 9,
}Variants
NotApproved = 0
InvalidOwner = 1
The owner of the input isn’t set to the program address generated by the program.
EmptySupply = 2
The input token account is empty.
InvalidInput = 3
The input token is invalid for swap.
IncorrectLpMint = 4
Address of the provided pool token mint is incorrect
ExceededSlippage = 5
Exceeds desired slippage limit
ZeroTradingTokens = 6
Given pool token amount results in zero trading tokens
NotSupportMint = 7
InvalidVault = 8
InitLpAmountTooLess = 9
Implementations